import argparse
from terminalbot.bot import get_message, send_message, is_private_group

def main():
    parser = argparse.ArgumentParser(description="Send and receive messages from a Telegram group")
    parser.add_argument('--token', required=True, help='Telegram bot token')
    parser.add_argument('--id', required=True, help='Telegram group chat ID')
    parser.add_argument('--message', help='Message to send to the group')
    parser.add_argument('--message-receive', help='Message to send after receiving a message')

    args = parser.parse_args()

    if args.message:
        send_message(args.token, args.id, args.message)
        print("Your message sent to the Telegram group")
    else:
        message = get_message(args.token, args.id)
        if message:
            print(message)
            if args.message_receive:
                send_message(args.token, args.id, args.message_receive)
if __name__ == '__main__':
    main()



import requests
import os
import json
import sys

class TelegramBot:
    def __init__(self, bot_token, group_chat_id):
        self.bot_token = bot_token
        self.group_chat_id = group_chat_id
        self.api_url = f'https://api.telegram.org/bot{bot_token}/'
        self.cookies_file = self.get_cookies_file_path()
        self.ensure_cookies_file_exists()
        self.last_update_id = self.load_last_update_id()

    def get_cookies_file_path(self):
        if getattr(sys, 'frozen', False):
            base_dir = sys._MEIPASS
        else:
            base_dir = os.path.dirname(__file__)
        
        return os.path.join(base_dir, 'terminalbot_cookies.json')

    def ensure_cookies_file_exists(self):
        if not os.path.exists(self.cookies_file):
            with open(self.cookies_file, 'w') as f:
                json.dump({'group_chat_id': self.group_chat_id, 'last_update_id': None}, f)

    def get_updates(self):
        params = {'timeout': 100, 'offset': self.last_update_id + 1 if self.last_update_id else None}
        response = requests.get(self.api_url + 'getUpdates', params=params)
        if response.status_code == 200:
            return response.json()
        else:
            return None

    def get_message(self):
        updates = self.get_updates()
        if updates and 'result' in updates:
            for update in updates['result']:
                update_id = update['update_id']
                if self.last_update_id is None or update_id > self.last_update_id:
                    self.last_update_id = update_id
                    self.save_last_update_id()
                    if 'message' in update and 'text' in update['message']:
                        return update['message']['text']
        return None

    def send_message(self, text):
        params = {'chat_id': self.group_chat_id, 'text': text}
        requests.post(self.api_url + 'sendMessage', params=params)

    def load_last_update_id(self):
        if os.path.exists(self.cookies_file):
            try:
                with open(self.cookies_file, 'r') as f:
                    data = json.load(f)
                    if data.get('group_chat_id') != self.group_chat_id:
                        self.save_last_update_id(reset=True)
                        return None
                    return data.get('last_update_id')
            except (json.JSONDecodeError, KeyError):
                self.save_last_update_id(reset=True)
                return None
        return None

    def save_last_update_id(self, reset=False):
        data = {
            'group_chat_id': self.group_chat_id,
            'last_update_id': None if reset else self.last_update_id
        }
        with open(self.cookies_file, 'w') as f:
            json.dump(data, f)

    def is_private_group(self):
        return str(self.group_chat_id).startswith('-')

def get_message(bot_token, group_chat_id):
    bot = TelegramBot(bot_token, group_chat_id)
    return bot.get_message()

def send_message(bot_token, group_chat_id, message):
    bot = TelegramBot(bot_token, group_chat_id)
    bot.send_message(message)

def is_private_group(bot_token, group_chat_id):
    bot = TelegramBot(bot_token, group_chat_id)
    return bot.is_private_group()



from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='terminalbot',
    version='1.60.1',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    entry_points={
        'console_scripts': [
            'terminalbot=terminalbot.cli:main',
        ],
    },
    package_data={
        'terminalbot': ['terminalbot_cookies.json'],
    },
    author='Fidal',
    author_email='mrfidal@proton.me',
    description='A package to interact with a Telegram group by sending and receiving messages',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://mrfidal.in/cyber-security/terminalbot',  
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    keywords='telegram bot messaging automation',
)
